@@ -701,9 +701,7 @@ nautilus_burn_make_iso (const char *filename,
 							 GTK_BUTTONS_CLOSE,
 							 _("Not enough space"));
 			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-								  ngettext("Not enough space to store disc image (%ld Megabyte needed)",
-									   "Not enough space to store disc image (%ld Megabytes needed)",
-									   iso_size / 512),
+								  "Not enough space to store disc image (%ld MiB needed)",
 								  iso_size / 512);
 			gtk_window_set_title (GTK_WINDOW (dialog),
 					      _("Not enough space"));
